@@ -1,17 +1,27 @@
 // R CMD SHLIB -I'/usr/include/R' -L'/usr/lib64/R/lib'  -lRlapack -lRblas nominate.c
 // R CMD SHLIB nominate.c  -lRlapack -lRBlas
 
+#ifndef  USE_FC_LEN_T
+# define USE_FC_LEN_T
+#endif
+#include <Rconfig.h>
+#include <R_ext/BLAS.h>
+#ifndef FCONE
+# define FCONE
+#endif
+
 #include <stdio.h>
 #include <errno.h>
 #include <stdlib.h>
 #include <R.h>
 #include <Rmath.h>
 #include <R_ext/Lapack.h>
-#include <R_ext/BLAS.h>
 #define MAXVOTES 100000
 #define SLICE_W 8
 #define SLICE_P 3
 
+
+
 typedef struct{
     int row, col, vote;
 //    int icpsr,period;
@@ -525,11 +535,11 @@ void genScaleParams(int nrow, int ncol,int dims,double **idealpts, double **yeal
 
     S = (double *) malloc(dims * dims * sizeof(double));
 
-    dgemm_(&trans,&notrans,&dims,&dims,&nrow,&alpha,*idealpts,&nrow,*idealpts,&nrow,&beta,S,&dims);         // Calculate outer product
+    dgemm_(&trans,&notrans,&dims,&dims,&nrow,&alpha,*idealpts,&nrow,*idealpts,&nrow,&beta,S,&dims FCONE FCONE);         // Calculate outer product
     riwish(nrow-1,S,dims,Sideal);                                                                          //  Generate wishart draw
-    dgemm_(&trans,&notrans,&dims,&dims,&ncol,&alpha,*yealocs,&ncol,*yealocs,&ncol,&beta,S,&dims);
+    dgemm_(&trans,&notrans,&dims,&dims,&ncol,&alpha,*yealocs,&ncol,*yealocs,&ncol,&beta,S,&dims FCONE FCONE);
     riwish(ncol-1,S,dims,Syea);
-    dgemm_(&trans,&notrans,&dims,&dims,&ncol,&alpha,*naylocs,&ncol,*naylocs,&ncol,&beta,S,&dims);
+    dgemm_(&trans,&notrans,&dims,&dims,&ncol,&alpha,*naylocs,&ncol,*naylocs,&ncol,&beta,S,&dims FCONE FCONE);
     riwish(ncol-1,S,dims,Snay);
 
     free(S);
@@ -608,7 +618,7 @@ void rwish(int v, double *S, int dims, double *output) {
     Scopy = (double *) malloc(dims * dims * sizeof(double));
 
     for(i=0;i<(dims*dims);i++) Scopy[i] = S[i];                         //copy S, so it leaves unchanged
-    dpotrf_(&uplo,&dims,Scopy,&dims,&info);                              // take Cholesky of S
+    dpotrf_(&uplo,&dims,Scopy,&dims,&info FCONE);                              // take Cholesky of S
 
     for(j=0;j<dims;j++){
         for(i=0;i<=j;i++){
@@ -631,8 +641,8 @@ void rwish(int v, double *S, int dims, double *output) {
     }
 */
 
-    dgemm_(&notrans,&notrans,&dims,&dims,&dims,&alpha,output,&dims,Scopy,&dims,&beta,temp,&dims);       // generates Z %*% S intermediate matrix
-    dgemm_(&trans,&notrans,&dims,&dims,&dims,&alpha,temp,&dims,temp,&dims,&beta,output,&dims);   // generates Wishart of S via crossproduct
+    dgemm_(&notrans,&notrans,&dims,&dims,&dims,&alpha,output,&dims,Scopy,&dims,&beta,temp,&dims FCONE FCONE);       // generates Z %*% S intermediate matrix
+    dgemm_(&trans,&notrans,&dims,&dims,&dims,&alpha,temp,&dims,temp,&dims,&beta,output,&dims FCONE FCONE);   // generates Wishart of S via crossproduct
 
     free(ipiv);
     free(temp);
@@ -687,8 +697,8 @@ double calcPrior(double *sample, int dims, double *scaleParam){
 
     temp = (double *) malloc(dims * sizeof(double));
 
-    dgemm_(&notrans,&notrans,&one,&dims,&dims,&alpha,sample,&one,scaleParam,&dims,&beta,temp,&one);  //temp = sample %*% scaleParam
-    dgemm_(&notrans,&notrans,&one,&one,&dims,&alpha,temp,&one,sample,&dims,&beta,&prior,&one);  //prior = temp %*% sample
+    dgemm_(&notrans,&notrans,&one,&dims,&dims,&alpha,sample,&one,scaleParam,&dims,&beta,temp,&one FCONE FCONE);  //temp = sample %*% scaleParam
+    dgemm_(&notrans,&notrans,&one,&one,&dims,&alpha,temp,&one,sample,&dims,&beta,&prior,&one FCONE FCONE);  //prior = temp %*% sample
 
     free(temp);
     return(prior);
